// block.js
(function(blocks, element, blockEditor) {

	var el = element.createElement,
		useBlockProps = blockEditor.useBlockProps,
		currentRequest = null;
	blocks.registerBlockType('sided/sided-debate-selector', {
		apiVersion: 1,
		title: 'Select Poll',
		icon: el("img", {
			src: "https://sided.co/favicon.ico",
			alt: "sided",
			height: "20px",
			width: "20px",
		}, ),
		description: "Insert a debate from existing debates.",
		category: "widgets",
		attributes: {
			selectedDebate: {
				type: "integer",
				default: null
			},
			searchKeyword: {
				type: "string",
				default: null
			},
			embedded: {
				type: "string",
				default: null
			}
		},

		edit: function(props) {
			window.props = props;
			function searchDebate(event) {
				var $ = jQuery;
				var thisElement = $(event.target);		
				props.setAttributes({
					searchKeyword: event.target.value
				});
				if (event.target.value.length > 0 && event.target.value.length < 3) {
					return false;
				}
				if (currentRequest != null) currentRequest.abort();
				currentRequest = $.ajax({
					url: ajaxurl,
					type: 'get',
					data: {
						action: 'wpa_fetch_debates',
						searchText: event.target.value,
						results_per_page: event.target.value.length === 0 ? 10 : 999
					},
					success: function(data) {
						thisElement.next('.searchResult').html('');
						var dataArray = $.parseJSON(data);
						if (dataArray.count > 0) {
							$.each(dataArray.rows, function(key, value) {
								thisElement.next('.searchResult').append('<li><a class="debate-item" data-did="' + value['id'] + '">' + value['thesis'] + '</a></li>');
							});
						} else {
							thisElement.next('.searchResult').append('<li>No debate found!</li>');
						}

						var items = document.getElementsByClassName('searchResult');
						for (var i = 0; i < items.length; i++) {
						  items[i].addEventListener("click", insertShortcode);
						}
					},
					error: function(data) {
						thisElement.next('.searchResult').html('');
						//thisElement.next('.searchResult').append('<li>Error occured!</li>');
					}
				})
				event.preventDefault();
			}

			function insertShortcode(event){
				if (event.target && event.target.matches("a.debate-item")) {
					var $ = jQuery;
					var thisElement = $(event.target);
					var dId = thisElement.data('did');
					var dThesis = thisElement.text();
					props.setAttributes({
						selectedDebate: Number(dId),
						searchKeyword: dThesis,
						embedded: 'debate-embedded'
					});
					thisElement.parents('.searchResult').html('');
				}
			}

			function editBlockBtnClick(event) {
				props.setAttributes({
					embedded: props.attributes.embedded == '' ? 'debate-embedded' : ''
				});
			}
			function clearSearch(event){
				props.setAttributes({
					searchKeyword: '',
				});
				currentRequest.abort();
			}

			children = [];

			children.push(
				el(
					'label', {
						className: ""
					},
					"Search Polls"
				),
				el(
					'div', {
						className: "searchKeyword-wrap",
					},
					props.attributes.searchKeyword && props.attributes.searchKeyword.length > 0 ? el(
						'span', {
							onClick: clearSearch
							},
							'+'
					) : '',
					el(
						'input', {
							className: "searchKeyword",
							placeholder: "Type here",
							value: props.attributes.searchKeyword,
							onChange: searchDebate,
							onFocus: searchDebate,
							tabIndex:"-1"
						}
					),
					el(
						'ul', {
							className: "searchResult"
						}
					),
				),
				props.attributes.selectedDebate ? el(
					'button', {
						className: "edit-block-btn ",
						onClick: editBlockBtnClick
					},
					'Cancel'
				) : ''
			);

			var embeddedClass = props.attributes.embedded;

			return el(
					'div', {
						className: "sided-wp-plugin-wrapper"
					},
					el(
						'div', {
							className: "components-placeholder " + embeddedClass
						},
						el(
							'div', {
								className: "edit-block-wrap ",
								/*onBlur: searchDebate,*/
							},
							children
						),
						el(
							'div', {
								className: "confirm-block"
							},
							'[sided-debate-embed debate-id="' + props.attributes.selectedDebate + '"]',
							el(
								'button', {
									className: "edit-block-btn",
								onClick: editBlockBtnClick
								},
								'Edit Poll'
							)
						)
					),
			);
		},

		save: function(props) {
			var dId = props.attributes.selectedDebate;
			if (dId === null) {
				return null;
			}
			return '[sided-debate-embed debate-id="' + dId + '"]';
		},
	});



	var el = element.createElement,
		useBlockProps = blockEditor.useBlockProps,
		currentRequest = null;

	blocks.registerBlockType('sided/sided-debate-creator', {
		apiVersion: 1,
		title: 'Create Poll',
		icon: el("img", {
			src: "https://sided.co/favicon.ico",
			alt: "sided",
			height: "20px",
			width: "20px",
		}, ),
		description: "Create new debate and embed into page.",
		category: "widgets",
		attributes: {
			selectedDebate: {
				type: "integer",
				default: null
			},
			embedded: {
				type: "string",
				default: false
			},
			debateCreated: {
				type: "string",
				default: false
			}
			

		},

		edit: function(props) {
			window.props = props;

			window.addEventListener('message', function(e){
				if(e.data.did) {
					window.selectedDebate = e.data.did;
					props.setAttributes({
						debateCreated: true
					});
				}

			});

			function setSelectedDebate(){
				props.setAttributes({
					selectedDebate: Number(selectedDebate),
					embedded: true
				});
			}

			children = [];

			children.push(
				el(
					'div', {
						className: "searchKeyword-wrap",
					},
					props.attributes.selectedDebate || props.attributes.debateCreated ? '' : el(
						'iframe', {
							src: 'admin.php?page=create-debate-from-block&&sided_hide_force=true'
						}
					),
					props.attributes.selectedDebate ? el(
						'div', {
							className: ""
						},
						'[sided-debate-embed debate-id="' + props.attributes.selectedDebate + '"]'
					) : '',
					props.attributes.selectedDebate || props.attributes.debateCreated === false ? '' : el(
							'p', {
							},
							'Success! Your poll has been created.'
							),
					props.attributes.selectedDebate || props.attributes.debateCreated === false ? '' :	el(
							'button', {
								id:"setSelectedDebate",
								className: "edit-block-btn",
								onClick: setSelectedDebate
							},
							'Insert this poll'
						),
				)
			);

			return el(
						'div', {
							className: "sided-wp-plugin-wrapper"
						},
						el(
							'div', {
								className: "components-placeholder",
							},
							children
						)
					);
		},

		save: function(props) {
			var dId = props.attributes.selectedDebate;
			if (dId === null) {
				return null;
			}
			return '[sided-debate-embed debate-id="' + dId + '"]';
		},
	});
})(window.wp.blocks, window.wp.element, window.wp.blockEditor);